==> apache-tinkerpop-3.4.13-src.zip: tinkerpop-3.4.13/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/step/map/LoopsStep.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal.step.map;

import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
import org.apache.tinkerpop.gremlin.process.traversal.Traverser;

/**
 * @author Daniel Kuppitz (http://gremlin.guru)
 */
public final class LoopsStep<S> extends MapStep<S, Integer> {

    private String loopName;

    public LoopsStep(final Traversal.Admin traversal, final String loopName) {
        super(traversal);
        this.loopName = loopName;
    }

    @Override
    protected Integer map(final Traverser.Admin<S> traverser) {
        return traverser.loops(this.loopName);
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) return true;
        if (!(o instanceof LoopsStep)) return false;
        if (!super.equals(o)) return false;

        final LoopsStep<?> loopsStep = (LoopsStep<?>) o;

        return loopName != null ? loopName.equals(loopsStep.loopName) : loopsStep.loopName == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + (loopName != null ? loopName.hashCode() : 0);
        return result;
    }

}

==> apache-tinkerpop-3.7.5-src.zip: tinkerpop-3.7.5/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/step/map/LoopsStep.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal.step.map;

import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
import org.apache.tinkerpop.gremlin.process.traversal.Traverser;

/**
 * @author Daniel Kuppitz (http://gremlin.guru)
 */
public final class LoopsStep<S> extends ScalarMapStep<S, Integer> {

    private String loopName;

    public LoopsStep(final Traversal.Admin traversal, final String loopName) {
        super(traversal);
        this.loopName = loopName;
    }

    @Override
    protected Integer map(final Traverser.Admin<S> traverser) {
        return traverser.loops(this.loopName);
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) return true;
        if (!(o instanceof LoopsStep)) return false;
        if (!super.equals(o)) return false;

        final LoopsStep<?> loopsStep = (LoopsStep<?>) o;

        return loopName != null ? loopName.equals(loopsStep.loopName) : loopsStep.loopName == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + (loopName != null ? loopName.hashCode() : 0);
        return result;
    }

}
